@@ -1,12 +1,12 @@
 "groupseq" <-
-function( mode=chosenMode )
+function( mode="g" )
 {
   #default is gui mode
   if(missing(mode))
   {
     guiMode()
   }
-  
+
   # "c" is console mode
   else if(mode=="c")
        {
@@ -23,4 +23,4 @@ function( mode=chosenMode )
        }
 }
 
-.onAttach <- function(libname, pkgname) {groupseq()}
\ No newline at end of file
+.onAttach <- function(libname, pkgname) {groupseq()}
